==> print-manager-4.14.2.tar.xz: print-manager-4.14.2/print-manager-kded/PrintManagerKded.h <==
/***************************************************************************
 *   Copyright (C) 2010-2012 by Daniel Nicoletti                           *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef PRINTMANAGERKDED_H
#define PRINTMANAGERKDED_H

#include <KDEDModule>

#include <QVariantList>

class NewPrinterNotification;
class PrintManagerKded : public KDEDModule
{
    Q_OBJECT
public:
    PrintManagerKded(QObject *parent, const QVariantList &args);
    ~PrintManagerKded();
    
private slots:
    void loadThread();

private:
    NewPrinterNotification *m_newPrinterNotification;
};

#endif // PRINTMANAGERKDED_H

==> print-manager-19.04.1.tar.xz: print-manager-19.04.1/print-manager-kded/PrintManagerKded.h <==
/***************************************************************************
 *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef PRINTMANAGERKDED_H
#define PRINTMANAGERKDED_H

#include <KDEDModule>
#include <KPluginFactory>

#include <QVariantList>

class PrintManagerKded : public KDEDModule
{
    Q_OBJECT
public:
    PrintManagerKded(QObject *parent, const QVariantList &args);
    ~PrintManagerKded();
};

K_PLUGIN_FACTORY(PrintDFactory, registerPlugin<PrintManagerKded>();)

#endif // PRINTMANAGERKDED_H
